# context-script

Used to be integrated via the GTM to any web page and perform a completed scan to capture consumer behaviour in our platform.

## Demo app

Go to the [demo scan url](https://tn.gg/K8ThR99e) to test the latest version of the `context-script`.

<br/>

## Account setup

1. Go to the [Product Cloud Team Management Settings page](https://dashboard.evrythng.com/product-cloud/settings/team-management) (`ACCESS TOKENS` tab) and generate an AccessToken with `WebApplication` role
1. Go to the [Dashboard Products page](https://dashboard.evrythng.com/resources/products) and create a product
1. Set up basic redirection for the product, target page would be https://quizzical-brahmagupta-c71fe9.netlify.app with all query params configured

### Redirection config

In order to configure redirection with the context-script create a rule with the following mandatory settings:

1.  Add condition -> `Action type | is | scans` - to prevent rule triggering during implicitScan
1.  Specify `contextScriptRedirection: true` in constants - necessary check to prevent other rules from triggering redirections (which leads to infinite redirection loops)

<br/>

Example of the setup can be found in [this project](https://dashboard.evrythng.com/projects/VxSwU3xrGtxQpGBGhPDFVd2b/applications/VSbRd3m7Dhe9rNXp8hb8tgUh?project=VxSwU3xrGtxQpGBGhPDFVd2b). Ask `evt_engineering` slack channel to invite you into `ARNALDO'S MASTER ACCOUNT` in production, if you dont have the access.

<br/>

## Local development

```
yarn install
yarn start
```

A browser tab with a `rerun context-script` button would be
Open browser dev tools in order to see console logs.
After making code changes and saving click `rerun context-script` button to rerun the script with latest changes.

Ask `evt_engineering` slack channel to invite you into `Amplify Master Test Account` in production, so that you could change redirection rules.

## Deploy to NPM (QA)

In order to deploy to QA:

1.  increment the current version and make it `alpha` or `beta`
1.  create `pre-release` tag in GitHub with `alpha` or `beta` word in version
1.  update version in [GTM context-script container](https://tagmanager.google.com/#/container/accounts/6003039479/containers/49715422/workspaces/2)

## Deploy to NPM (release)

1.  remove `alpha`/`beta` from the version
1.  create `release` tag in GitHub
1.  update version in [GTM context-script container](https://tagmanager.google.com/#/container/accounts/6003039479/containers/49715422/workspaces/2)

## **WARNING**:

Please, change only `dev` rules during development, `test` ones refers to the demo page.

<br/>

## GTM variables and query params description

Requires cookies to be allowed by user or `GTM_ARE_COOKIES_BLOCKED` variable to be set according to the current cookies consent.

Accepts following query parameters:

- `evt_token` - required if `GTM_EVT_TOKEN` GTM variable is not specified
- `evt_implicit_scan_id` - optional
- `evt_product_id` - required, 'scan not performed' message would be displayed in console if not specified (the case when user manually opens the web page rather than scanning QR code)
- `evt_thng_id` - optional

<br/>

## GTM setup

Create custom html tag in GTM and specify the following (variables block can be removed, if not - according GTM variables needs to be defined):

```
<script>
  var GTM_EVT_REGION = '{{EVRYTHNG API Region}}'; // optional, region is 'us' if not specified
  var GTM_EVT_TOKEN = '{{EVRYTHNG API Token}}'; // optional, required if `evt_token` query param is not specified
  var GTM_EVT_ARE_COOKIES_BLOCKED = '{{Cookies Are Blocked}}'; // optional, value is 'false' if not specified
</script>

<script>
  var contextScript = document.createElement('script');
  contextScript.setAttribute('src', 'https://cdn.jsdelivr.net/npm/@evrythng/context-script@1/dist/context-script.js?v=' + Date.now());
  document.head.appendChild(contextScript);
</script>
```

Configuration example can be found in this [GTM context-script container](https://tagmanager.google.com/#/container/accounts/6003039479/containers/49715422/workspaces/2)

## Flow diagram

See [context-page docs](https://github.com/evrythng/context-page#flow-diagram)
